/* SerializableObjectModel-TDocument-Test.c generated by valac 0.34.6, the Vala compiler
 * generated from SerializableObjectModel-TDocument-Test.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */

#include <glib.h>
#include <glib-object.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <stdio.h>


#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST (serializable_object_model_tdocument_test_get_type ())
#define SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST, SerializableObjectModelTDocumentTest))
#define SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST, SerializableObjectModelTDocumentTestClass))
#define IS_SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST))
#define IS_SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST))
#define SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST, SerializableObjectModelTDocumentTestClass))

typedef struct _SerializableObjectModelTDocumentTest SerializableObjectModelTDocumentTest;
typedef struct _SerializableObjectModelTDocumentTestClass SerializableObjectModelTDocumentTestClass;
typedef struct _SerializableObjectModelTDocumentTestPrivate SerializableObjectModelTDocumentTestPrivate;

#define TYPE_OBJECT_MODEL (object_model_get_type ())
#define OBJECT_MODEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OBJECT_MODEL, ObjectModel))
#define OBJECT_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OBJECT_MODEL, ObjectModelClass))
#define IS_OBJECT_MODEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OBJECT_MODEL))
#define IS_OBJECT_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OBJECT_MODEL))
#define OBJECT_MODEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OBJECT_MODEL, ObjectModelClass))

typedef struct _ObjectModel ObjectModel;
typedef struct _ObjectModelClass ObjectModelClass;

#define TYPE_COMPUTER (computer_get_type ())
#define COMPUTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMPUTER, Computer))
#define COMPUTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMPUTER, ComputerClass))
#define IS_COMPUTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMPUTER))
#define IS_COMPUTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMPUTER))
#define COMPUTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMPUTER, ComputerClass))

typedef struct _Computer Computer;
typedef struct _ComputerClass ComputerClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_MANUAL (manual_get_type ())
#define MANUAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MANUAL, Manual))
#define MANUAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MANUAL, ManualClass))
#define IS_MANUAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MANUAL))
#define IS_MANUAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MANUAL))
#define MANUAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MANUAL, ManualClass))

typedef struct _Manual Manual;
typedef struct _ManualClass ManualClass;

#define TYPE_PACKAGE (package_get_type ())
#define PACKAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PACKAGE, Package))
#define PACKAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PACKAGE, PackageClass))
#define IS_PACKAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PACKAGE))
#define IS_PACKAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PACKAGE))
#define PACKAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PACKAGE, PackageClass))

typedef struct _Package Package;
typedef struct _PackageClass PackageClass;

#define TYPE_MONITOR (monitor_get_type ())
#define MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MONITOR, Monitor))
#define MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MONITOR, MonitorClass))
#define IS_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MONITOR))
#define IS_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MONITOR))
#define MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MONITOR, MonitorClass))

typedef struct _Monitor Monitor;
typedef struct _MonitorClass MonitorClass;

#define TYPE_CONFIGURATION (configuration_get_type ())
#define CONFIGURATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION, Configuration))
#define CONFIGURATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION, ConfigurationClass))
#define IS_CONFIGURATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION))
#define IS_CONFIGURATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION))
#define CONFIGURATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION, ConfigurationClass))

typedef struct _Configuration Configuration;
typedef struct _ConfigurationClass ConfigurationClass;

#define TYPE_NAME_SPACE (name_space_get_type ())
#define NAME_SPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NAME_SPACE, NameSpace))
#define NAME_SPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NAME_SPACE, NameSpaceClass))
#define IS_NAME_SPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NAME_SPACE))
#define IS_NAME_SPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NAME_SPACE))
#define NAME_SPACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NAME_SPACE, NameSpaceClass))

typedef struct _NameSpace NameSpace;
typedef struct _NameSpaceClass NameSpaceClass;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializableObjectModelTDocumentTest {
	GXmlTest parent_instance;
	SerializableObjectModelTDocumentTestPrivate * priv;
};

struct _SerializableObjectModelTDocumentTestClass {
	GXmlTestClass parent_class;
};


static gpointer serializable_object_model_tdocument_test_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_gxml_test (GValue* value, gpointer v_object);
void value_take_gxml_test (GValue* value, gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_object_model_tdocument_test_get_type (void) G_GNUC_CONST;
enum  {
	SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST_DUMMY_PROPERTY
};
void serializable_object_model_tdocument_test_add_tests (void);
static void __lambda30_ (void);
GType object_model_get_type (void) G_GNUC_CONST;
GType computer_get_type (void) G_GNUC_CONST;
Computer* computer_new (void);
Computer* computer_construct (GType object_type);
static void ___lambda30__gtest_func (void);
static void __lambda31_ (void);
GType manual_get_type (void) G_GNUC_CONST;
Manual* manual_new (void);
Manual* manual_construct (GType object_type);
const gchar* manual_get_document (Manual* self);
gint manual_get_pages (Manual* self);
gchar* manual_get_contents (Manual* self);
static void ___lambda31__gtest_func (void);
static void __lambda32_ (void);
GType package_get_type (void) G_GNUC_CONST;
Package* package_new (void);
Package* package_construct (GType object_type);
static void ___lambda32__gtest_func (void);
static void __lambda33_ (void);
GArray* package_get_tags (Package* self);
static void ___lambda33__gtest_func (void);
static void __lambda34_ (void);
GType monitor_get_type (void) G_GNUC_CONST;
Monitor* monitor_new (void);
Monitor* monitor_construct (GType object_type);
void monitor_set_resolution (Monitor* self, const gchar* value);
void monitor_set_ac_power (Monitor* self, gint value);
void monitor_set_dc_power (Monitor* self, gint value);
static void ___lambda34__gtest_func (void);
static void __lambda35_ (void);
GType configuration_get_type (void) G_GNUC_CONST;
Configuration* configuration_new (void);
Configuration* configuration_construct (GType object_type);
void configuration_set_device (Configuration* self, const gchar* value);
static void ___lambda35__gtest_func (void);
static void __lambda36_ (void);
GType name_space_get_type (void) G_GNUC_CONST;
NameSpace* name_space_new (void);
NameSpace* name_space_construct (GType object_type);
static void ___lambda36__gtest_func (void);
static void __lambda37_ (void);
static void ___lambda37__gtest_func (void);
static void __lambda38_ (void);
static void ___lambda38__gtest_func (void);
SerializableObjectModelTDocumentTest* serializable_object_model_tdocument_test_new (void);
SerializableObjectModelTDocumentTest* serializable_object_model_tdocument_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);


static void __lambda30_ (void) {
	GError * _inner_error_ = NULL;
	{
		Computer* computer = NULL;
		Computer* _tmp0_ = NULL;
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlNode* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		GXmlNode* m = NULL;
		GXmlNode* _tmp12_ = NULL;
		GXmlNode* _tmp13_ = NULL;
		GXmlNode* _tmp14_ = NULL;
		GeeMap* _tmp15_ = NULL;
		GeeMap* _tmp16_ = NULL;
		GeeMap* _tmp17_ = NULL;
		gpointer _tmp18_ = NULL;
		GXmlNode* _tmp19_ = NULL;
		GXmlNode* mod = NULL;
		GXmlNode* _tmp20_ = NULL;
		GXmlNode* _tmp21_ = NULL;
		GXmlNode* _tmp22_ = NULL;
		GeeMap* _tmp23_ = NULL;
		GeeMap* _tmp24_ = NULL;
		GeeMap* _tmp25_ = NULL;
		gpointer _tmp26_ = NULL;
		GXmlNode* _tmp27_ = NULL;
		GXmlNode* c = NULL;
		GXmlNode* _tmp28_ = NULL;
		GXmlNode* _tmp29_ = NULL;
		GXmlNode* _tmp30_ = NULL;
		GeeMap* _tmp31_ = NULL;
		GeeMap* _tmp32_ = NULL;
		GeeMap* _tmp33_ = NULL;
		gpointer _tmp34_ = NULL;
		GXmlNode* _tmp35_ = NULL;
		GXmlNode* g = NULL;
		GXmlNode* _tmp36_ = NULL;
		GXmlNode* _tmp37_ = NULL;
		GXmlNode* _tmp38_ = NULL;
		GeeMap* _tmp39_ = NULL;
		GeeMap* _tmp40_ = NULL;
		GeeMap* _tmp41_ = NULL;
		gpointer _tmp42_ = NULL;
		GXmlNode* _tmp43_ = NULL;
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp0_ = computer_new ();
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		computer = _tmp0_;
#line 36 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp1_ = gxml_tdocument_new ();
#line 36 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		doc = _tmp1_;
#line 37 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) computer, (GXmlNode*) doc, &_inner_error_);
#line 37 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp3_ = _tmp2_;
#line 37 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp3_);
#line 37 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 37 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (doc);
#line 37 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (computer);
#line 274 "SerializableObjectModel-TDocument-Test.c"
			goto __catch62_g_error;
		}
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp5_ = _tmp4_;
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp6_ = _tmp5_;
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp7_ = gxml_node_get_name (_tmp6_);
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp8_ = _tmp7_;
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp9_ = _tmp8_;
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp10_ = g_utf8_strdown (_tmp9_, (gssize) -1);
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp11_ = _tmp10_;
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (g_strcmp0 (_tmp11_, "computer") == 0, "doc.root.name.down () == \"computer\"");
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp11_);
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp9_);
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp6_);
#line 39 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp12_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 39 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp13_ = _tmp12_;
#line 39 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp14_ = _tmp13_;
#line 39 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp15_ = gxml_node_get_attrs (_tmp14_);
#line 39 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp16_ = _tmp15_;
#line 39 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp17_ = _tmp16_;
#line 39 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp18_ = gee_map_get (_tmp17_, "manufacturer");
#line 39 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp19_ = (GXmlNode*) _tmp18_;
#line 39 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp17_);
#line 39 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp14_);
#line 39 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		m = _tmp19_;
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (m != NULL, "m != null");
#line 41 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp20_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 41 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp21_ = _tmp20_;
#line 41 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp22_ = _tmp21_;
#line 41 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp23_ = gxml_node_get_attrs (_tmp22_);
#line 41 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp24_ = _tmp23_;
#line 41 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp25_ = _tmp24_;
#line 41 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp26_ = gee_map_get (_tmp25_, "model");
#line 41 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp27_ = (GXmlNode*) _tmp26_;
#line 41 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp25_);
#line 41 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp22_);
#line 41 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		mod = _tmp27_;
#line 42 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (mod != NULL, "mod != null");
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp28_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp29_ = _tmp28_;
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp30_ = _tmp29_;
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp31_ = gxml_node_get_attrs (_tmp30_);
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp32_ = _tmp31_;
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp33_ = _tmp32_;
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp34_ = gee_map_get (_tmp33_, "cores");
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp35_ = (GXmlNode*) _tmp34_;
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp33_);
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp30_);
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		c = _tmp35_;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (c != NULL, "c != null");
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp36_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp37_ = _tmp36_;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp38_ = _tmp37_;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp39_ = gxml_node_get_attrs (_tmp38_);
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp40_ = _tmp39_;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp41_ = _tmp40_;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp42_ = gee_map_get (_tmp41_, "ghz");
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp43_ = (GXmlNode*) _tmp42_;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp41_);
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp38_);
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g = _tmp43_;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (g != NULL, "g != null");
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (g);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (c);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (mod);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (m);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (computer);
#line 409 "SerializableObjectModel-TDocument-Test.c"
	}
	goto __finally62;
	__catch62_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp44_ = NULL;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		e = _inner_error_;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_inner_error_ = NULL;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp44_ = e->message;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_message ("SerializableObjectModel-TDocument-Test.vala:50: %s", _tmp44_);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_assert_not_reached ();
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_error_free0 (e);
#line 428 "SerializableObjectModel-TDocument-Test.c"
	}
	__finally62:
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_clear_error (&_inner_error_);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		return;
#line 439 "SerializableObjectModel-TDocument-Test.c"
	}
}


static void ___lambda30__gtest_func (void) {
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	__lambda30_ ();
#line 447 "SerializableObjectModel-TDocument-Test.c"
}


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1412 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1413 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	result = self;
#line 1413 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 459 "SerializableObjectModel-TDocument-Test.c"
}


static void __lambda31_ (void) {
	GXmlTDocument* doc = NULL;
	GXmlTDocument* _tmp0_ = NULL;
	Manual* manual = NULL;
	Manual* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	GError * _inner_error_ = NULL;
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp0_ = gxml_tdocument_new ();
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	doc = _tmp0_;
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp1_ = manual_new ();
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	manual = _tmp1_;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp2_ = manual_get_document (manual);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp3_ = _tmp2_;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_vala_assert (g_strcmp0 (_tmp3_, "MANUAL DOCUMENTATION") == 0, "manual.document == \"MANUAL DOCUMENTATION\"");
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp4_ = manual_get_pages (manual);
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp5_ = _tmp4_;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_vala_assert (_tmp5_ == 3, "manual.pages == 3");
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp6_ = manual_get_contents (manual);
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp7_ = _tmp6_;
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_vala_assert (g_strcmp0 (_tmp7_, "TEXT INTO THE MANUAL DOCUMENT") == 0, "manual.get_contents () == \"TEXT INTO THE MANUAL DOCUMENT\"");
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_g_free0 (_tmp7_);
#line 503 "SerializableObjectModel-TDocument-Test.c"
	{
		GXmlNode* _tmp8_ = NULL;
		GXmlNode* _tmp9_ = NULL;
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp8_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) manual, (GXmlNode*) doc, &_inner_error_);
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp9_ = _tmp8_;
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp9_);
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 515 "SerializableObjectModel-TDocument-Test.c"
			goto __catch63_g_error;
		}
	}
	goto __finally63;
	__catch63_g_error:
	{
		GError* e = NULL;
		FILE* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		e = _inner_error_;
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_inner_error_ = NULL;
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp10_ = stdout;
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp11_ = e->message;
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp12_ = string_to_string (_tmp11_);
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		fprintf (_tmp10_, "%s", _tmp12_);
#line 67 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_assert_not_reached ();
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_error_free0 (e);
#line 542 "SerializableObjectModel-TDocument-Test.c"
	}
	__finally63:
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (manual);
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_clear_error (&_inner_error_);
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		return;
#line 557 "SerializableObjectModel-TDocument-Test.c"
	}
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (manual);
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (doc);
#line 563 "SerializableObjectModel-TDocument-Test.c"
}


static void ___lambda31__gtest_func (void) {
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	__lambda31_ ();
#line 570 "SerializableObjectModel-TDocument-Test.c"
}


static void __lambda32_ (void) {
	GXmlTDocument* doc = NULL;
	GXmlTDocument* _tmp0_ = NULL;
	Package* package = NULL;
	Package* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp0_ = gxml_tdocument_new ();
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	doc = _tmp0_;
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp1_ = package_new ();
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	package = _tmp1_;
#line 588 "SerializableObjectModel-TDocument-Test.c"
	{
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlNode* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gboolean _tmp10_ = FALSE;
		GXmlElement* element = NULL;
		GXmlNode* _tmp21_ = NULL;
		GXmlNode* _tmp22_ = NULL;
		GXmlNode* source = NULL;
		GeeMap* _tmp23_ = NULL;
		GeeMap* _tmp24_ = NULL;
		GeeMap* _tmp25_ = NULL;
		gpointer _tmp26_ = NULL;
		GXmlNode* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gboolean _tmp31_ = FALSE;
		GXmlNode* destiny = NULL;
		GeeMap* _tmp39_ = NULL;
		GeeMap* _tmp40_ = NULL;
		GeeMap* _tmp41_ = NULL;
		gpointer _tmp42_ = NULL;
		GXmlNode* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		gchar* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
		gboolean _tmp47_ = FALSE;
#line 76 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) package, (GXmlNode*) doc, &_inner_error_);
#line 76 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp3_ = _tmp2_;
#line 76 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp3_);
#line 76 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 630 "SerializableObjectModel-TDocument-Test.c"
			goto __catch64_g_error;
		}
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp5_ = _tmp4_;
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp6_ = _tmp5_;
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp7_ = gxml_node_get_name (_tmp6_);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp8_ = _tmp7_;
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp9_ = _tmp8_;
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp10_ = g_strcmp0 (_tmp9_, "package") != 0;
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp9_);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp6_);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (_tmp10_) {
#line 653 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp11_ = NULL;
			GXmlNode* _tmp12_ = NULL;
			GXmlNode* _tmp13_ = NULL;
			GXmlNode* _tmp14_ = NULL;
			gchar* _tmp15_ = NULL;
			gchar* _tmp16_ = NULL;
			gchar* _tmp17_ = NULL;
			const gchar* _tmp18_ = NULL;
			gchar* _tmp19_ = NULL;
			gchar* _tmp20_ = NULL;
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp11_ = stdout;
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp12_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp13_ = _tmp12_;
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp14_ = _tmp13_;
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp15_ = gxml_node_get_name (_tmp14_);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp16_ = _tmp15_;
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp17_ = _tmp16_;
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp18_ = string_to_string (_tmp17_);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp19_ = g_strconcat ("ERROR MANUAL:  GElement: ", _tmp18_, "\n", NULL);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp20_ = _tmp19_;
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp11_, "%s", _tmp20_);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp20_);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp17_);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (_tmp14_);
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 694 "SerializableObjectModel-TDocument-Test.c"
		}
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp21_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp22_ = _tmp21_;
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		element = G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, GXML_TYPE_ELEMENT, GXmlElement);
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp23_ = gxml_node_get_attrs ((GXmlNode*) element);
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp24_ = _tmp23_;
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp25_ = _tmp24_;
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp26_ = gee_map_get (_tmp25_, "source");
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp27_ = (GXmlNode*) _tmp26_;
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp25_);
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		source = _tmp27_;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (source == NULL) {
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 720 "SerializableObjectModel-TDocument-Test.c"
		}
#line 84 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp28_ = gxml_node_get_value (source);
#line 84 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp29_ = _tmp28_;
#line 84 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp30_ = _tmp29_;
#line 84 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp31_ = g_strcmp0 (_tmp30_, "Mexico") != 0;
#line 84 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp30_);
#line 84 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (_tmp31_) {
#line 734 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp32_ = NULL;
			gchar* _tmp33_ = NULL;
			gchar* _tmp34_ = NULL;
			gchar* _tmp35_ = NULL;
			const gchar* _tmp36_ = NULL;
			gchar* _tmp37_ = NULL;
			gchar* _tmp38_ = NULL;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp32_ = stdout;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp33_ = gxml_node_get_value (source);
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp34_ = _tmp33_;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp35_ = _tmp34_;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp36_ = string_to_string (_tmp35_);
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp37_ = g_strconcat ("ERROR PACKAGE: source: ", _tmp36_, "\n", NULL);
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp38_ = _tmp37_;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp32_, "%s", _tmp38_);
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp38_);
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp35_);
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 764 "SerializableObjectModel-TDocument-Test.c"
		}
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp39_ = gxml_node_get_attrs ((GXmlNode*) element);
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp40_ = _tmp39_;
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp41_ = _tmp40_;
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp42_ = gee_map_get (_tmp41_, "destiny");
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp43_ = (GXmlNode*) _tmp42_;
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp41_);
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		destiny = _tmp43_;
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (destiny == NULL) {
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 784 "SerializableObjectModel-TDocument-Test.c"
		}
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp44_ = gxml_node_get_value (destiny);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp45_ = _tmp44_;
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp46_ = _tmp45_;
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp47_ = g_strcmp0 (_tmp46_, "World") != 0;
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp46_);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (_tmp47_) {
#line 798 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp48_ = NULL;
			gchar* _tmp49_ = NULL;
			gchar* _tmp50_ = NULL;
			gchar* _tmp51_ = NULL;
			const gchar* _tmp52_ = NULL;
			gchar* _tmp53_ = NULL;
			gchar* _tmp54_ = NULL;
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp48_ = stdout;
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp49_ = gxml_node_get_value (destiny);
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp50_ = _tmp49_;
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp51_ = _tmp50_;
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp52_ = string_to_string (_tmp51_);
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp53_ = g_strconcat ("ERROR PACKAGE: source: ", _tmp52_, "\n", NULL);
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp54_ = _tmp53_;
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp48_, "%s", _tmp54_);
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp54_);
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp51_);
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 828 "SerializableObjectModel-TDocument-Test.c"
		}
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (destiny);
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (source);
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (element);
#line 836 "SerializableObjectModel-TDocument-Test.c"
	}
	goto __finally64;
	__catch64_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp55_ = NULL;
		const gchar* _tmp56_ = NULL;
		gchar* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		e = _inner_error_;
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_inner_error_ = NULL;
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp55_ = e->message;
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp56_ = string_to_string (_tmp55_);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp57_ = g_strconcat ("Error: ", _tmp56_, NULL);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp58_ = _tmp57_;
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_message ("SerializableObjectModel-TDocument-Test.vala:96: %s", _tmp58_);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp58_);
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_assert_not_reached ();
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_error_free0 (e);
#line 866 "SerializableObjectModel-TDocument-Test.c"
	}
	__finally64:
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (package);
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_clear_error (&_inner_error_);
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		return;
#line 881 "SerializableObjectModel-TDocument-Test.c"
	}
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (package);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (doc);
#line 887 "SerializableObjectModel-TDocument-Test.c"
}


static void ___lambda32__gtest_func (void) {
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	__lambda32_ ();
#line 894 "SerializableObjectModel-TDocument-Test.c"
}


static void __lambda33_ (void) {
	GXmlTDocument* doc = NULL;
	GXmlTDocument* _tmp0_ = NULL;
	Package* package = NULL;
	Package* _tmp1_ = NULL;
	GArray* _tmp2_ = NULL;
	GArray* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	GArray* _tmp5_ = NULL;
	GArray* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	GArray* _tmp8_ = NULL;
	GArray* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	GError * _inner_error_ = NULL;
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp0_ = gxml_tdocument_new ();
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	doc = _tmp0_;
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp1_ = package_new ();
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	package = _tmp1_;
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp2_ = package_get_tags (package);
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp3_ = _tmp2_;
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp4_ = g_strdup ("Computer");
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	g_array_append_val (_tmp3_, _tmp4_);
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp5_ = package_get_tags (package);
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp6_ = _tmp5_;
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp7_ = g_strdup ("Customer");
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	g_array_append_val (_tmp6_, _tmp7_);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp8_ = package_get_tags (package);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp9_ = _tmp8_;
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp10_ = g_strdup ("Sale");
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	g_array_append_val (_tmp9_, _tmp10_);
#line 945 "SerializableObjectModel-TDocument-Test.c"
	{
		GXmlNode* _tmp11_ = NULL;
		GXmlNode* _tmp12_ = NULL;
		GXmlNode* _tmp13_ = NULL;
		GXmlNode* _tmp14_ = NULL;
		GXmlNode* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gboolean _tmp19_ = FALSE;
		GXmlElement* element = NULL;
		GXmlNode* _tmp20_ = NULL;
		GXmlNode* _tmp21_ = NULL;
		gboolean com = FALSE;
		gboolean cus = FALSE;
		gboolean sal = FALSE;
		gboolean _tmp54_ = FALSE;
		gboolean _tmp56_ = FALSE;
		gboolean _tmp58_ = FALSE;
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp11_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) package, (GXmlNode*) doc, &_inner_error_);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp12_ = _tmp11_;
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp12_);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 973 "SerializableObjectModel-TDocument-Test.c"
			goto __catch65_g_error;
		}
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp13_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp14_ = _tmp13_;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp15_ = _tmp14_;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp16_ = gxml_node_get_name (_tmp15_);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp17_ = _tmp16_;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp18_ = _tmp17_;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp19_ = g_strcmp0 (_tmp18_, "package") != 0;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp18_);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp15_);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (_tmp19_) {
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 998 "SerializableObjectModel-TDocument-Test.c"
		}
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp20_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp21_ = _tmp20_;
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		element = G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, GXML_TYPE_ELEMENT, GXmlElement);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		com = FALSE;
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		cus = FALSE;
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		sal = FALSE;
#line 1012 "SerializableObjectModel-TDocument-Test.c"
		{
			GeeBidirList* _n_list = NULL;
			GXmlElement* _tmp22_ = NULL;
			GeeBidirList* _tmp23_ = NULL;
			GeeBidirList* _tmp24_ = NULL;
			gint _n_size = 0;
			GeeBidirList* _tmp25_ = NULL;
			gint _tmp26_ = 0;
			gint _tmp27_ = 0;
			gint _n_index = 0;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp22_ = element;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp23_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp22_);
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp24_ = _tmp23_;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_n_list = _tmp24_;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp25_ = _n_list;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp26_ = gee_collection_get_size ((GeeCollection*) _tmp25_);
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp27_ = _tmp26_;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_n_size = _tmp27_;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_n_index = -1;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			while (TRUE) {
#line 1043 "SerializableObjectModel-TDocument-Test.c"
				gint _tmp28_ = 0;
				gint _tmp29_ = 0;
				gint _tmp30_ = 0;
				GXmlNode* n = NULL;
				GeeBidirList* _tmp31_ = NULL;
				gint _tmp32_ = 0;
				gpointer _tmp33_ = NULL;
				GXmlNode* _tmp34_ = NULL;
				gchar* _tmp35_ = NULL;
				gchar* _tmp36_ = NULL;
				gchar* _tmp37_ = NULL;
				gboolean _tmp38_ = FALSE;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp28_ = _n_index;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_n_index = _tmp28_ + 1;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp29_ = _n_index;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp30_ = _n_size;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				if (!(_tmp29_ < _tmp30_)) {
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					break;
#line 1068 "SerializableObjectModel-TDocument-Test.c"
				}
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp31_ = _n_list;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp32_ = _n_index;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp33_ = gee_list_get ((GeeList*) _tmp31_, _tmp32_);
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				n = (GXmlNode*) _tmp33_;
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp34_ = n;
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp35_ = gxml_node_get_name (_tmp34_);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp36_ = _tmp35_;
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp37_ = _tmp36_;
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp38_ = g_strcmp0 (_tmp37_, "tag") == 0;
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_g_free0 (_tmp37_);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				if (_tmp38_) {
#line 1092 "SerializableObjectModel-TDocument-Test.c"
					GXmlNode* _tmp39_ = NULL;
					gchar* _tmp40_ = NULL;
					gchar* _tmp41_ = NULL;
					gchar* _tmp42_ = NULL;
					gboolean _tmp43_ = FALSE;
					GXmlNode* _tmp44_ = NULL;
					gchar* _tmp45_ = NULL;
					gchar* _tmp46_ = NULL;
					gchar* _tmp47_ = NULL;
					gboolean _tmp48_ = FALSE;
					GXmlNode* _tmp49_ = NULL;
					gchar* _tmp50_ = NULL;
					gchar* _tmp51_ = NULL;
					gchar* _tmp52_ = NULL;
					gboolean _tmp53_ = FALSE;
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp39_ = n;
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp40_ = gxml_element_get_content (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, GXML_TYPE_ELEMENT, GXmlElement));
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp41_ = _tmp40_;
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp42_ = _tmp41_;
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp43_ = g_strcmp0 (_tmp42_, "Computer") == 0;
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_g_free0 (_tmp42_);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					if (_tmp43_) {
#line 121 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
						com = TRUE;
#line 1124 "SerializableObjectModel-TDocument-Test.c"
					}
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp44_ = n;
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp45_ = gxml_element_get_content (G_TYPE_CHECK_INSTANCE_CAST (_tmp44_, GXML_TYPE_ELEMENT, GXmlElement));
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp46_ = _tmp45_;
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp47_ = _tmp46_;
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp48_ = g_strcmp0 (_tmp47_, "Customer") == 0;
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_g_free0 (_tmp47_);
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					if (_tmp48_) {
#line 123 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
						cus = TRUE;
#line 1142 "SerializableObjectModel-TDocument-Test.c"
					}
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp49_ = n;
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp50_ = gxml_element_get_content (G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, GXML_TYPE_ELEMENT, GXmlElement));
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp51_ = _tmp50_;
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp52_ = _tmp51_;
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp53_ = g_strcmp0 (_tmp52_, "Sale") == 0;
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_g_free0 (_tmp52_);
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					if (_tmp53_) {
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
						sal = TRUE;
#line 1160 "SerializableObjectModel-TDocument-Test.c"
					}
				}
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_g_object_unref0 (n);
#line 1165 "SerializableObjectModel-TDocument-Test.c"
			}
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (_n_list);
#line 1169 "SerializableObjectModel-TDocument-Test.c"
		}
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp54_ = com;
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (!_tmp54_) {
#line 1175 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp55_ = NULL;
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp55_ = stdout;
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp55_, "%s", "ERROR PACKAGE tag Computer not found!");
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1183 "SerializableObjectModel-TDocument-Test.c"
		}
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp56_ = cus;
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (!_tmp56_) {
#line 1189 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp57_ = NULL;
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp57_ = stdout;
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp57_, "%s", "ERROR PACKAGE tag Customer not found!");
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1197 "SerializableObjectModel-TDocument-Test.c"
		}
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp58_ = sal;
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (!_tmp58_) {
#line 1203 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp59_ = NULL;
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp59_ = stdout;
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp59_, "%s", "ERROR PACKAGE tag Sale not found!");
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1211 "SerializableObjectModel-TDocument-Test.c"
		}
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (element);
#line 1215 "SerializableObjectModel-TDocument-Test.c"
	}
	goto __finally65;
	__catch65_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp60_ = NULL;
		const gchar* _tmp61_ = NULL;
		gchar* _tmp62_ = NULL;
		gchar* _tmp63_ = NULL;
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		e = _inner_error_;
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_inner_error_ = NULL;
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp60_ = e->message;
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp61_ = string_to_string (_tmp60_);
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp62_ = g_strconcat ("Error: ", _tmp61_, NULL);
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp63_ = _tmp62_;
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_message ("SerializableObjectModel-TDocument-Test.vala:142: %s", _tmp63_);
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp63_);
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_assert_not_reached ();
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_error_free0 (e);
#line 1245 "SerializableObjectModel-TDocument-Test.c"
	}
	__finally65:
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (package);
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_clear_error (&_inner_error_);
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		return;
#line 1260 "SerializableObjectModel-TDocument-Test.c"
	}
#line 101 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (package);
#line 101 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (doc);
#line 1266 "SerializableObjectModel-TDocument-Test.c"
}


static void ___lambda33__gtest_func (void) {
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	__lambda33_ ();
#line 1273 "SerializableObjectModel-TDocument-Test.c"
}


static void __lambda34_ (void) {
	GXmlTDocument* doc = NULL;
	GXmlTDocument* _tmp0_ = NULL;
	Monitor* monitor = NULL;
	Monitor* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp0_ = gxml_tdocument_new ();
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	doc = _tmp0_;
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp1_ = monitor_new ();
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	monitor = _tmp1_;
#line 1291 "SerializableObjectModel-TDocument-Test.c"
	{
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlNode* _tmp6_ = NULL;
		gboolean _tmp7_ = FALSE;
		GXmlElement* element = NULL;
		GXmlNode* _tmp9_ = NULL;
		GXmlNode* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gboolean _tmp14_ = FALSE;
		GXmlNode* ac = NULL;
		GeeMap* _tmp22_ = NULL;
		GeeMap* _tmp23_ = NULL;
		GeeMap* _tmp24_ = NULL;
		gpointer _tmp25_ = NULL;
		GXmlNode* _tmp26_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gboolean _tmp31_ = FALSE;
		GXmlNode* dc = NULL;
		GeeMap* _tmp39_ = NULL;
		GeeMap* _tmp40_ = NULL;
		GeeMap* _tmp41_ = NULL;
		gpointer _tmp42_ = NULL;
		GXmlNode* _tmp43_ = NULL;
		gchar* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
		gboolean _tmp48_ = FALSE;
		GXmlNode* r = NULL;
		GeeMap* _tmp56_ = NULL;
		GeeMap* _tmp57_ = NULL;
		GeeMap* _tmp58_ = NULL;
		gpointer _tmp59_ = NULL;
		GXmlNode* _tmp60_ = NULL;
		gchar* _tmp62_ = NULL;
		gchar* _tmp63_ = NULL;
		gchar* _tmp64_ = NULL;
		gboolean _tmp65_ = FALSE;
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		monitor_set_resolution (monitor, "1204x720");
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		monitor_set_ac_power (monitor, 120);
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		monitor_set_dc_power (monitor, 125);
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) monitor, (GXmlNode*) doc, &_inner_error_);
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp3_ = _tmp2_;
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp3_);
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1350 "SerializableObjectModel-TDocument-Test.c"
			goto __catch66_g_error;
		}
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp5_ = _tmp4_;
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp6_ = _tmp5_;
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp7_ = _tmp6_ == NULL;
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp6_);
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (_tmp7_) {
#line 1365 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp8_ = NULL;
#line 157 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp8_ = stdout;
#line 157 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp8_, "ERROR MONITOR: No root Element");
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1373 "SerializableObjectModel-TDocument-Test.c"
		}
#line 160 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp9_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 160 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp10_ = _tmp9_;
#line 160 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		element = G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GXML_TYPE_ELEMENT, GXmlElement);
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp11_ = gxml_node_get_name ((GXmlNode*) element);
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp12_ = _tmp11_;
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp13_ = _tmp12_;
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp14_ = g_strcmp0 (_tmp13_, "monitor") != 0;
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp13_);
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (_tmp14_) {
#line 1393 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp15_ = NULL;
			gchar* _tmp16_ = NULL;
			gchar* _tmp17_ = NULL;
			gchar* _tmp18_ = NULL;
			const gchar* _tmp19_ = NULL;
			gchar* _tmp20_ = NULL;
			gchar* _tmp21_ = NULL;
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp15_ = stdout;
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp16_ = gxml_node_get_name ((GXmlNode*) element);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp17_ = _tmp16_;
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp18_ = _tmp17_;
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp19_ = string_to_string (_tmp18_);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp20_ = g_strconcat ("ERROR MONITOR: root GElement ", _tmp19_, NULL);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp21_ = _tmp20_;
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp15_, "%s", _tmp21_);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp21_);
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp18_);
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1423 "SerializableObjectModel-TDocument-Test.c"
		}
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp22_ = gxml_node_get_attrs ((GXmlNode*) element);
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp23_ = _tmp22_;
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp24_ = _tmp23_;
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp25_ = gee_map_get (_tmp24_, "AcPower");
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp26_ = (GXmlNode*) _tmp25_;
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp24_);
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		ac = _tmp26_;
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (ac == NULL) {
#line 1441 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp27_ = NULL;
#line 167 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp27_ = stdout;
#line 167 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp27_, "%s", "ERROR MONITOR: attribute AcPower not found");
#line 168 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1449 "SerializableObjectModel-TDocument-Test.c"
		}
#line 170 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp28_ = gxml_node_get_value (ac);
#line 170 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp29_ = _tmp28_;
#line 170 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp30_ = _tmp29_;
#line 170 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp31_ = g_strcmp0 (_tmp30_, "120") != 0;
#line 170 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp30_);
#line 170 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (_tmp31_) {
#line 1463 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp32_ = NULL;
			gchar* _tmp33_ = NULL;
			gchar* _tmp34_ = NULL;
			gchar* _tmp35_ = NULL;
			const gchar* _tmp36_ = NULL;
			gchar* _tmp37_ = NULL;
			gchar* _tmp38_ = NULL;
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp32_ = stdout;
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp33_ = gxml_node_get_value (ac);
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp34_ = _tmp33_;
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp35_ = _tmp34_;
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp36_ = string_to_string (_tmp35_);
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp37_ = g_strconcat ("ERROR MONITOR: AcPower value ", _tmp36_, NULL);
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp38_ = _tmp37_;
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp32_, "%s", _tmp38_);
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp38_);
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp35_);
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1493 "SerializableObjectModel-TDocument-Test.c"
		}
#line 174 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp39_ = gxml_node_get_attrs ((GXmlNode*) element);
#line 174 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp40_ = _tmp39_;
#line 174 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp41_ = _tmp40_;
#line 174 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp42_ = gee_map_get (_tmp41_, "DcPower");
#line 174 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp43_ = (GXmlNode*) _tmp42_;
#line 174 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp41_);
#line 174 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		dc = _tmp43_;
#line 175 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (dc == NULL) {
#line 1511 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp44_ = NULL;
#line 176 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp44_ = stdout;
#line 176 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp44_, "%s", "ERROR MONITOR: attribute DcPower not found");
#line 177 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1519 "SerializableObjectModel-TDocument-Test.c"
		}
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp45_ = gxml_node_get_value (dc);
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp46_ = _tmp45_;
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp47_ = _tmp46_;
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp48_ = g_strcmp0 (_tmp47_, "125") != 0;
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp47_);
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (_tmp48_) {
#line 1533 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp49_ = NULL;
			gchar* _tmp50_ = NULL;
			gchar* _tmp51_ = NULL;
			gchar* _tmp52_ = NULL;
			const gchar* _tmp53_ = NULL;
			gchar* _tmp54_ = NULL;
			gchar* _tmp55_ = NULL;
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp49_ = stdout;
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp50_ = gxml_node_get_value (dc);
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp51_ = _tmp50_;
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp52_ = _tmp51_;
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp53_ = string_to_string (_tmp52_);
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp54_ = g_strconcat ("ERROR MONITOR: AcPower value ", _tmp53_, NULL);
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp55_ = _tmp54_;
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp49_, "%s", _tmp55_);
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp55_);
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp52_);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1563 "SerializableObjectModel-TDocument-Test.c"
		}
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp56_ = gxml_node_get_attrs ((GXmlNode*) element);
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp57_ = _tmp56_;
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp58_ = _tmp57_;
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp59_ = gee_map_get (_tmp58_, "resolution");
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp60_ = (GXmlNode*) _tmp59_;
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp58_);
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		r = _tmp60_;
#line 184 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (r == NULL) {
#line 1581 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp61_ = NULL;
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp61_ = stdout;
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp61_, "%s", "ERROR MONITOR: attribute resolution not found");
#line 186 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1589 "SerializableObjectModel-TDocument-Test.c"
		}
#line 188 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp62_ = gxml_node_get_value (r);
#line 188 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp63_ = _tmp62_;
#line 188 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp64_ = _tmp63_;
#line 188 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp65_ = g_strcmp0 (_tmp64_, "1204x720") != 0;
#line 188 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp64_);
#line 188 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (_tmp65_) {
#line 1603 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp66_ = NULL;
			gchar* _tmp67_ = NULL;
			gchar* _tmp68_ = NULL;
			gchar* _tmp69_ = NULL;
			const gchar* _tmp70_ = NULL;
			gchar* _tmp71_ = NULL;
			gchar* _tmp72_ = NULL;
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp66_ = stdout;
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp67_ = gxml_node_get_value (r);
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp68_ = _tmp67_;
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp69_ = _tmp68_;
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp70_ = string_to_string (_tmp69_);
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp71_ = g_strconcat ("ERROR MONITOR: resolution value ", _tmp70_, NULL);
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp72_ = _tmp71_;
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp66_, "%s", _tmp72_);
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp72_);
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp69_);
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1633 "SerializableObjectModel-TDocument-Test.c"
		}
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (r);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (dc);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (ac);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (element);
#line 1643 "SerializableObjectModel-TDocument-Test.c"
	}
	goto __finally66;
	__catch66_g_error:
	{
		GError* e = NULL;
		FILE* _tmp73_ = NULL;
		const gchar* _tmp74_ = NULL;
		const gchar* _tmp75_ = NULL;
		gchar* _tmp76_ = NULL;
		gchar* _tmp77_ = NULL;
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		e = _inner_error_;
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_inner_error_ = NULL;
#line 194 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp73_ = stdout;
#line 194 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp74_ = e->message;
#line 194 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp75_ = string_to_string (_tmp74_);
#line 194 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp76_ = g_strconcat ("Error: ", _tmp75_, NULL);
#line 194 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp77_ = _tmp76_;
#line 194 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		fprintf (_tmp73_, "%s", _tmp77_);
#line 194 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp77_);
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_assert_not_reached ();
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_error_free0 (e);
#line 1676 "SerializableObjectModel-TDocument-Test.c"
	}
	__finally66:
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (monitor);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_clear_error (&_inner_error_);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		return;
#line 1691 "SerializableObjectModel-TDocument-Test.c"
	}
#line 147 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (monitor);
#line 147 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (doc);
#line 1697 "SerializableObjectModel-TDocument-Test.c"
}


static void ___lambda34__gtest_func (void) {
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	__lambda34_ ();
#line 1704 "SerializableObjectModel-TDocument-Test.c"
}


static void __lambda35_ (void) {
	GXmlTDocument* doc = NULL;
	GXmlTDocument* _tmp0_ = NULL;
	Configuration* configuration = NULL;
	Configuration* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 243 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp0_ = gxml_tdocument_new ();
#line 243 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	doc = _tmp0_;
#line 244 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_tmp1_ = configuration_new ();
#line 244 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	configuration = _tmp1_;
#line 245 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	configuration_set_device (configuration, "Controller");
#line 1724 "SerializableObjectModel-TDocument-Test.c"
	{
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlNode* _tmp6_ = NULL;
		gboolean _tmp7_ = FALSE;
		GXmlElement* element = NULL;
		GXmlNode* _tmp8_ = NULL;
		GXmlNode* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gboolean _tmp13_ = FALSE;
		gboolean found = FALSE;
		gboolean _tmp35_ = FALSE;
#line 247 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) configuration, (GXmlNode*) doc, &_inner_error_);
#line 247 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp3_ = _tmp2_;
#line 247 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp3_);
#line 247 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1749 "SerializableObjectModel-TDocument-Test.c"
			goto __catch67_g_error;
		}
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp5_ = _tmp4_;
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp6_ = _tmp5_;
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp7_ = _tmp6_ == NULL;
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp6_);
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (_tmp7_) {
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1766 "SerializableObjectModel-TDocument-Test.c"
		}
#line 255 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp8_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 255 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp9_ = _tmp8_;
#line 255 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		element = G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GXML_TYPE_ELEMENT, GXmlElement);
#line 256 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp10_ = gxml_node_get_name ((GXmlNode*) element);
#line 256 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp11_ = _tmp10_;
#line 256 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp12_ = _tmp11_;
#line 256 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp13_ = g_strcmp0 (_tmp12_, "Configuration") != 0;
#line 256 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp12_);
#line 256 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (_tmp13_) {
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1788 "SerializableObjectModel-TDocument-Test.c"
		}
#line 262 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		found = FALSE;
#line 1792 "SerializableObjectModel-TDocument-Test.c"
		{
			GeeList* _n_list = NULL;
			GeeList* _tmp14_ = NULL;
			GeeList* _tmp15_ = NULL;
			gint _n_size = 0;
			GeeList* _tmp16_ = NULL;
			gint _tmp17_ = 0;
			gint _tmp18_ = 0;
			gint _n_index = 0;
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp14_ = gxml_node_get_namespaces ((GXmlNode*) element);
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp15_ = _tmp14_;
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_n_list = _tmp15_;
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp16_ = _n_list;
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp17_ = gee_collection_get_size ((GeeCollection*) _tmp16_);
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp18_ = _tmp17_;
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_n_size = _tmp18_;
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_n_index = -1;
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			while (TRUE) {
#line 1820 "SerializableObjectModel-TDocument-Test.c"
				gint _tmp19_ = 0;
				gint _tmp20_ = 0;
				gint _tmp21_ = 0;
				GXmlNamespace* n = NULL;
				GeeList* _tmp22_ = NULL;
				gint _tmp23_ = 0;
				gpointer _tmp24_ = NULL;
				gboolean _tmp25_ = FALSE;
				GXmlNamespace* _tmp26_ = NULL;
				gchar* _tmp27_ = NULL;
				gchar* _tmp28_ = NULL;
				gchar* _tmp29_ = NULL;
				gboolean _tmp30_ = FALSE;
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp19_ = _n_index;
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_n_index = _tmp19_ + 1;
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp20_ = _n_index;
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp21_ = _n_size;
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				if (!(_tmp20_ < _tmp21_)) {
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					break;
#line 1846 "SerializableObjectModel-TDocument-Test.c"
				}
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp22_ = _n_list;
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp23_ = _n_index;
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp24_ = gee_list_get (_tmp22_, _tmp23_);
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				n = (GXmlNamespace*) _tmp24_;
#line 265 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp26_ = n;
#line 265 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp27_ = gxml_namespace_get_prefix (_tmp26_);
#line 265 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp28_ = _tmp27_;
#line 265 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp29_ = _tmp28_;
#line 265 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp30_ = g_strcmp0 (_tmp29_, "om") == 0;
#line 265 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_g_free0 (_tmp29_);
#line 265 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				if (_tmp30_) {
#line 1870 "SerializableObjectModel-TDocument-Test.c"
					GXmlNamespace* _tmp31_ = NULL;
					gchar* _tmp32_ = NULL;
					gchar* _tmp33_ = NULL;
					gchar* _tmp34_ = NULL;
#line 265 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp31_ = n;
#line 265 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp32_ = gxml_namespace_get_uri (_tmp31_);
#line 265 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp33_ = _tmp32_;
#line 265 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp34_ = _tmp33_;
#line 265 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp25_ = g_strcmp0 (_tmp34_, "http://www.gnome.org/gxml/0.4") == 0;
#line 265 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_g_free0 (_tmp34_);
#line 1887 "SerializableObjectModel-TDocument-Test.c"
				} else {
#line 265 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp25_ = FALSE;
#line 1891 "SerializableObjectModel-TDocument-Test.c"
				}
#line 265 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				if (_tmp25_) {
#line 266 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					found = TRUE;
#line 1897 "SerializableObjectModel-TDocument-Test.c"
				}
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_g_object_unref0 (n);
#line 1901 "SerializableObjectModel-TDocument-Test.c"
			}
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (_n_list);
#line 1905 "SerializableObjectModel-TDocument-Test.c"
		}
#line 268 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp35_ = found;
#line 268 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (!_tmp35_) {
#line 275 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1913 "SerializableObjectModel-TDocument-Test.c"
		}
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (element);
#line 1917 "SerializableObjectModel-TDocument-Test.c"
	}
	goto __finally67;
	__catch67_g_error:
	{
		GError* e = NULL;
		FILE* _tmp36_ = NULL;
		const gchar* _tmp37_ = NULL;
		const gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		gchar* _tmp40_ = NULL;
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		e = _inner_error_;
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_inner_error_ = NULL;
#line 279 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp36_ = stdout;
#line 279 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp37_ = e->message;
#line 279 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp38_ = string_to_string (_tmp37_);
#line 279 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp39_ = g_strconcat ("Error: ", _tmp38_, NULL);
#line 279 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp40_ = _tmp39_;
#line 279 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		fprintf (_tmp36_, "%s", _tmp40_);
#line 279 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp40_);
#line 280 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_assert_not_reached ();
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_error_free0 (e);
#line 1950 "SerializableObjectModel-TDocument-Test.c"
	}
	__finally67:
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (configuration);
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_clear_error (&_inner_error_);
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		return;
#line 1965 "SerializableObjectModel-TDocument-Test.c"
	}
#line 242 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (configuration);
#line 242 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (doc);
#line 1971 "SerializableObjectModel-TDocument-Test.c"
}


static void ___lambda35__gtest_func (void) {
#line 241 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	__lambda35_ ();
#line 1978 "SerializableObjectModel-TDocument-Test.c"
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1376 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1376 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1377 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1377 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1377 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1377 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 1998 "SerializableObjectModel-TDocument-Test.c"
}


static void __lambda36_ (void) {
	GError * _inner_error_ = NULL;
	{
		NameSpace* ns = NULL;
		NameSpace* _tmp0_ = NULL;
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		gchar* str = NULL;
		gchar* _tmp4_ = NULL;
		gboolean _tmp5_ = FALSE;
#line 285 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp0_ = name_space_new ();
#line 285 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		ns = _tmp0_;
#line 286 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp1_ = gxml_tdocument_new ();
#line 286 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		doc = _tmp1_;
#line 287 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) ns, (GXmlNode*) doc, &_inner_error_);
#line 287 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp3_ = _tmp2_;
#line 287 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp3_);
#line 287 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 287 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (doc);
#line 287 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (ns);
#line 2034 "SerializableObjectModel-TDocument-Test.c"
			goto __catch68_g_error;
		}
#line 288 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp4_ = gxml_tnode_to_string ((GXmlTNode*) doc);
#line 288 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		str = _tmp4_;
#line 292 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp5_ = string_contains (str, "<namespace xmlns:gxml=\"http://www.gnome.org/GXml\"/>");
#line 292 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (_tmp5_, "\"<namespace xmlns:gxml=\\\"http://www.gnome.org/GXml\\\"/>\" in str");
#line 284 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (str);
#line 284 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 284 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (ns);
#line 2051 "SerializableObjectModel-TDocument-Test.c"
	}
	goto __finally68;
	__catch68_g_error:
	{
		GError* e = NULL;
#line 284 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		e = _inner_error_;
#line 284 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_inner_error_ = NULL;
#line 297 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_assert_not_reached ();
#line 284 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_error_free0 (e);
#line 2065 "SerializableObjectModel-TDocument-Test.c"
	}
	__finally68:
#line 284 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 284 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 284 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_clear_error (&_inner_error_);
#line 284 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		return;
#line 2076 "SerializableObjectModel-TDocument-Test.c"
	}
}


static void ___lambda36__gtest_func (void) {
#line 283 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	__lambda36_ ();
#line 2084 "SerializableObjectModel-TDocument-Test.c"
}


static void __lambda37_ (void) {
	GError * _inner_error_ = NULL;
	{
		Package* p = NULL;
		Package* _tmp0_ = NULL;
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlTDocument* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlElement* r = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlTDocument* _tmp6_ = NULL;
		GeeBidirList* _tmp7_ = NULL;
		GeeBidirList* _tmp8_ = NULL;
		GeeBidirList* _tmp9_ = NULL;
		GXmlElement* _tmp10_ = NULL;
		GXmlElement* _tmp11_ = NULL;
		GXmlElement* _tmp12_ = NULL;
		GXmlElement* _tmp13_ = NULL;
		Package* _tmp14_ = NULL;
		GXmlTDocument* _tmp15_ = NULL;
		Package* _tmp16_ = NULL;
		GeeMap* _tmp17_ = NULL;
		GeeMap* _tmp18_ = NULL;
		GeeMap* _tmp19_ = NULL;
		GXmlAttribute* ukattr = NULL;
		Package* _tmp20_ = NULL;
		GeeMap* _tmp21_ = NULL;
		GeeMap* _tmp22_ = NULL;
		GeeMap* _tmp23_ = NULL;
		gpointer _tmp24_ = NULL;
		GXmlAttribute* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
#line 302 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp0_ = package_new ();
#line 302 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		p = _tmp0_;
#line 303 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp1_ = gxml_tdocument_new ();
#line 303 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		doc = _tmp1_;
#line 304 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp3_ = doc;
#line 304 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp4_ = gxml_document_create_element ((GXmlDocument*) _tmp3_, "PACKAGE", &_inner_error_);
#line 304 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp2_ = _tmp4_;
#line 304 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 304 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (doc);
#line 304 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (p);
#line 2147 "SerializableObjectModel-TDocument-Test.c"
			goto __catch69_g_error;
		}
#line 304 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp5_ = _tmp2_;
#line 304 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp2_ = NULL;
#line 304 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		r = G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GXML_TYPE_ELEMENT, GXmlElement);
#line 305 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp6_ = doc;
#line 305 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp7_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp6_);
#line 305 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp8_ = _tmp7_;
#line 305 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp9_ = _tmp8_;
#line 305 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp10_ = r;
#line 305 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		gee_collection_add ((GeeCollection*) _tmp9_, (GXmlNode*) _tmp10_);
#line 305 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp9_);
#line 306 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp11_ = r;
#line 306 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		gxml_element_set_attr (_tmp11_, "source", "Mexico/North");
#line 307 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp12_ = r;
#line 307 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		gxml_element_set_attr (_tmp12_, "destiny", "Brazil");
#line 308 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp13_ = r;
#line 308 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		gxml_element_set_attr (_tmp13_, "Unknown", "2/4.04");
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp14_ = p;
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp15_ = doc;
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp14_, (GXmlNode*) _tmp15_, &_inner_error_);
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (r);
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (_tmp2_);
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (doc);
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (p);
#line 2198 "SerializableObjectModel-TDocument-Test.c"
			goto __catch69_g_error;
		}
#line 310 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp16_ = p;
#line 310 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp17_ = gxml_serializable_get_unknown_serializable_properties ((GXmlSerializable*) _tmp16_);
#line 310 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp18_ = _tmp17_;
#line 310 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp19_ = _tmp18_;
#line 310 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (_tmp19_ != NULL, "p.unknown_serializable_properties != null");
#line 310 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp19_);
#line 311 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp20_ = p;
#line 311 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp21_ = gxml_serializable_get_unknown_serializable_properties ((GXmlSerializable*) _tmp20_);
#line 311 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp22_ = _tmp21_;
#line 311 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp23_ = _tmp22_;
#line 311 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp24_ = gee_map_get (_tmp23_, "Unknown");
#line 311 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp25_ = (GXmlAttribute*) _tmp24_;
#line 311 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp23_);
#line 311 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		ukattr = _tmp25_;
#line 312 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (ukattr != NULL, "ukattr != null");
#line 313 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp26_ = gxml_node_get_name ((GXmlNode*) ukattr);
#line 313 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp27_ = _tmp26_;
#line 313 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp28_ = _tmp27_;
#line 313 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (g_strcmp0 (_tmp28_, "Unknown") == 0, "ukattr.name == \"Unknown\"");
#line 313 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp28_);
#line 314 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp29_ = gxml_node_get_value ((GXmlNode*) ukattr);
#line 314 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp30_ = _tmp29_;
#line 314 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp31_ = _tmp30_;
#line 314 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (g_strcmp0 (_tmp31_, "2/4.04") == 0, "ukattr.value == \"2/4.04\"");
#line 314 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp31_);
#line 301 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (ukattr);
#line 301 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (r);
#line 301 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp2_);
#line 301 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 301 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (p);
#line 2261 "SerializableObjectModel-TDocument-Test.c"
	}
	goto __finally69;
	__catch69_g_error:
	{
		GError* e = NULL;
#line 301 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		e = _inner_error_;
#line 301 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_inner_error_ = NULL;
#line 319 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_assert_not_reached ();
#line 301 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_error_free0 (e);
#line 2275 "SerializableObjectModel-TDocument-Test.c"
	}
	__finally69:
#line 301 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 301 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 301 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_clear_error (&_inner_error_);
#line 301 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		return;
#line 2286 "SerializableObjectModel-TDocument-Test.c"
	}
}


static void ___lambda37__gtest_func (void) {
#line 300 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	__lambda37_ ();
#line 2294 "SerializableObjectModel-TDocument-Test.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 336 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	return self ? g_object_ref (self) : NULL;
#line 2301 "SerializableObjectModel-TDocument-Test.c"
}


static void __lambda38_ (void) {
	GError * _inner_error_ = NULL;
	{
		Package* p = NULL;
		Package* _tmp0_ = NULL;
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlTDocument* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlElement* r = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlTDocument* _tmp6_ = NULL;
		GeeBidirList* _tmp7_ = NULL;
		GeeBidirList* _tmp8_ = NULL;
		GeeBidirList* _tmp9_ = NULL;
		GXmlElement* _tmp10_ = NULL;
		GXmlElement* _tmp11_ = NULL;
		GXmlElement* _tmp12_ = NULL;
		GXmlNode* _tmp13_ = NULL;
		GXmlTDocument* _tmp14_ = NULL;
		GXmlNode* _tmp15_ = NULL;
		GXmlElement* c = NULL;
		GXmlNode* _tmp16_ = NULL;
		GXmlElement* _tmp17_ = NULL;
		GeeBidirList* _tmp18_ = NULL;
		GeeBidirList* _tmp19_ = NULL;
		GeeBidirList* _tmp20_ = NULL;
		GXmlElement* _tmp21_ = NULL;
		GXmlElement* _tmp22_ = NULL;
		Package* _tmp23_ = NULL;
		GXmlTDocument* _tmp24_ = NULL;
		Package* _tmp25_ = NULL;
		GeeCollection* _tmp26_ = NULL;
		GeeCollection* _tmp27_ = NULL;
		GeeCollection* _tmp28_ = NULL;
		gboolean found = FALSE;
		GXmlNode* un = NULL;
		GXmlElement* _tmp29_ = NULL;
		GXmlNode* _tmp30_ = NULL;
		gboolean _tmp48_ = FALSE;
		GXmlNode* ukattr = NULL;
		GXmlNode* _tmp49_ = NULL;
		GeeMap* _tmp50_ = NULL;
		GeeMap* _tmp51_ = NULL;
		GeeMap* _tmp52_ = NULL;
		gpointer _tmp53_ = NULL;
		GXmlNode* _tmp54_ = NULL;
		gchar* _tmp55_ = NULL;
		gchar* _tmp56_ = NULL;
		gchar* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		gchar* _tmp59_ = NULL;
		gchar* _tmp60_ = NULL;
#line 324 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp0_ = package_new ();
#line 324 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		p = _tmp0_;
#line 325 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp1_ = gxml_tdocument_new ();
#line 325 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		doc = _tmp1_;
#line 326 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp3_ = doc;
#line 326 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp4_ = gxml_document_create_element ((GXmlDocument*) _tmp3_, "PACKAGE", &_inner_error_);
#line 326 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp2_ = _tmp4_;
#line 326 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 326 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (doc);
#line 326 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (p);
#line 2379 "SerializableObjectModel-TDocument-Test.c"
			goto __catch70_g_error;
		}
#line 326 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp5_ = _tmp2_;
#line 326 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp2_ = NULL;
#line 326 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		r = G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GXML_TYPE_ELEMENT, GXmlElement);
#line 327 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp6_ = doc;
#line 327 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp7_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp6_);
#line 327 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp8_ = _tmp7_;
#line 327 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp9_ = _tmp8_;
#line 327 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp10_ = r;
#line 327 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		gee_collection_add ((GeeCollection*) _tmp9_, (GXmlNode*) _tmp10_);
#line 327 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp9_);
#line 328 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp11_ = r;
#line 328 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		gxml_element_set_attr (_tmp11_, "source", "Mexico/North");
#line 329 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp12_ = r;
#line 329 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		gxml_element_set_attr (_tmp12_, "destiny", "Brazil");
#line 330 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp14_ = doc;
#line 330 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp15_ = gxml_document_create_element ((GXmlDocument*) _tmp14_, "Unknown", &_inner_error_);
#line 330 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp13_ = _tmp15_;
#line 330 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 330 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (r);
#line 330 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (_tmp2_);
#line 330 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (doc);
#line 330 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (p);
#line 2426 "SerializableObjectModel-TDocument-Test.c"
			goto __catch70_g_error;
		}
#line 330 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp16_ = _tmp13_;
#line 330 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp13_ = NULL;
#line 330 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		c = G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, GXML_TYPE_ELEMENT, GXmlElement);
#line 331 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp17_ = r;
#line 331 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp18_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp17_);
#line 331 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp19_ = _tmp18_;
#line 331 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp20_ = _tmp19_;
#line 331 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp21_ = c;
#line 331 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		gee_collection_add ((GeeCollection*) _tmp20_, (GXmlNode*) _tmp21_);
#line 331 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp20_);
#line 332 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp22_ = c;
#line 332 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		gxml_element_set_attr (_tmp22_, "prop", "value");
#line 333 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp23_ = p;
#line 333 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp24_ = doc;
#line 333 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp23_, (GXmlNode*) _tmp24_, &_inner_error_);
#line 333 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 333 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (c);
#line 333 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (_tmp13_);
#line 333 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (r);
#line 333 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (_tmp2_);
#line 333 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (doc);
#line 333 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (p);
#line 2473 "SerializableObjectModel-TDocument-Test.c"
			goto __catch70_g_error;
		}
#line 334 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp25_ = p;
#line 334 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp26_ = gxml_serializable_get_unknown_serializable_nodes ((GXmlSerializable*) _tmp25_);
#line 334 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp27_ = _tmp26_;
#line 334 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp28_ = _tmp27_;
#line 334 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (_tmp28_ != NULL, "p.unknown_serializable_nodes != null");
#line 334 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp28_);
#line 335 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		found = FALSE;
#line 336 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp29_ = c;
#line 336 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp30_ = _g_object_ref0 ((GXmlNode*) _tmp29_);
#line 336 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		un = _tmp30_;
#line 2496 "SerializableObjectModel-TDocument-Test.c"
		{
			GeeIterator* _n_it = NULL;
			Package* _tmp31_ = NULL;
			GeeCollection* _tmp32_ = NULL;
			GeeCollection* _tmp33_ = NULL;
			GeeCollection* _tmp34_ = NULL;
			GeeIterator* _tmp35_ = NULL;
			GeeIterator* _tmp36_ = NULL;
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp31_ = p;
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp32_ = gxml_serializable_get_unknown_serializable_nodes ((GXmlSerializable*) _tmp31_);
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp33_ = _tmp32_;
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp34_ = _tmp33_;
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp35_ = gee_iterable_iterator ((GeeIterable*) _tmp34_);
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_tmp36_ = _tmp35_;
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (_tmp34_);
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_n_it = _tmp36_;
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			while (TRUE) {
#line 2523 "SerializableObjectModel-TDocument-Test.c"
				GeeIterator* _tmp37_ = NULL;
				gboolean _tmp38_ = FALSE;
				GXmlNode* n = NULL;
				GeeIterator* _tmp39_ = NULL;
				gpointer _tmp40_ = NULL;
				GXmlNode* _tmp41_ = NULL;
				gchar* _tmp42_ = NULL;
				gchar* _tmp43_ = NULL;
				gchar* _tmp44_ = NULL;
				gboolean _tmp45_ = FALSE;
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp37_ = _n_it;
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp38_ = gee_iterator_next (_tmp37_);
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				if (!_tmp38_) {
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					break;
#line 2542 "SerializableObjectModel-TDocument-Test.c"
				}
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp39_ = _n_it;
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp40_ = gee_iterator_get (_tmp39_);
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				n = (GXmlNode*) _tmp40_;
#line 338 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp41_ = n;
#line 338 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp42_ = gxml_node_get_name (_tmp41_);
#line 338 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp43_ = _tmp42_;
#line 338 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp44_ = _tmp43_;
#line 338 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_tmp45_ = g_strcmp0 (_tmp44_, "Unknown") == 0;
#line 338 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_g_free0 (_tmp44_);
#line 338 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				if (_tmp45_) {
#line 2564 "SerializableObjectModel-TDocument-Test.c"
					GXmlNode* _tmp46_ = NULL;
					GXmlNode* _tmp47_ = NULL;
#line 339 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					found = TRUE;
#line 340 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp46_ = n;
#line 340 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_tmp47_ = _g_object_ref0 (_tmp46_);
#line 340 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					_g_object_unref0 (un);
#line 340 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
					un = _tmp47_;
#line 2577 "SerializableObjectModel-TDocument-Test.c"
				}
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
				_g_object_unref0 (n);
#line 2581 "SerializableObjectModel-TDocument-Test.c"
			}
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (_n_it);
#line 2585 "SerializableObjectModel-TDocument-Test.c"
		}
#line 343 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp48_ = found;
#line 343 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (_tmp48_, "found");
#line 344 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp49_ = un;
#line 344 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp50_ = gxml_node_get_attrs (_tmp49_);
#line 344 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp51_ = _tmp50_;
#line 344 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp52_ = _tmp51_;
#line 344 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp53_ = gee_map_get (_tmp52_, "prop");
#line 344 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp54_ = (GXmlNode*) _tmp53_;
#line 344 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp52_);
#line 344 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		ukattr = _tmp54_;
#line 345 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (ukattr != NULL, "ukattr != null");
#line 346 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp55_ = gxml_node_get_name (ukattr);
#line 346 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp56_ = _tmp55_;
#line 346 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp57_ = _tmp56_;
#line 346 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (g_strcmp0 (_tmp57_, "prop") == 0, "ukattr.name == \"prop\"");
#line 346 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp57_);
#line 347 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp58_ = gxml_node_get_value (ukattr);
#line 347 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp59_ = _tmp58_;
#line 347 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_tmp60_ = _tmp59_;
#line 347 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (g_strcmp0 (_tmp60_, "value") == 0, "ukattr.value == \"value\"");
#line 347 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp60_);
#line 323 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (ukattr);
#line 323 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (un);
#line 323 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (c);
#line 323 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp13_);
#line 323 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (r);
#line 323 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp2_);
#line 323 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 323 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (p);
#line 2645 "SerializableObjectModel-TDocument-Test.c"
	}
	goto __finally70;
	__catch70_g_error:
	{
		GError* e = NULL;
#line 323 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		e = _inner_error_;
#line 323 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_inner_error_ = NULL;
#line 352 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_assert_not_reached ();
#line 323 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		_g_error_free0 (e);
#line 2659 "SerializableObjectModel-TDocument-Test.c"
	}
	__finally70:
#line 323 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 323 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 323 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		g_clear_error (&_inner_error_);
#line 323 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
		return;
#line 2670 "SerializableObjectModel-TDocument-Test.c"
	}
}


static void ___lambda38__gtest_func (void) {
#line 322 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	__lambda38_ ();
#line 2678 "SerializableObjectModel-TDocument-Test.c"
}


void serializable_object_model_tdocument_test_add_tests (void) {
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/object_model/serialize/simple_object", ___lambda30__gtest_func);
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/object_model/serialize_object_contents", ___lambda31__gtest_func);
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/object_model/serialize_serializable_properties", ___lambda32__gtest_func);
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/object_model/serialize_array_property", ___lambda33__gtest_func);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/object_model/serialize_property_nick", ___lambda34__gtest_func);
#line 241 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/object_model/override_serialize", ___lambda35__gtest_func);
#line 283 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/object_model/set_namespace", ___lambda36__gtest_func);
#line 300 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/object_model/find-unknown_property", ___lambda37__gtest_func);
#line 322 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/object_model/find-unknown_node", ___lambda38__gtest_func);
#line 2701 "SerializableObjectModel-TDocument-Test.c"
}


SerializableObjectModelTDocumentTest* serializable_object_model_tdocument_test_construct (GType object_type) {
	SerializableObjectModelTDocumentTest* self = NULL;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	self = (SerializableObjectModelTDocumentTest*) gxml_test_construct (object_type);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	return self;
#line 2711 "SerializableObjectModel-TDocument-Test.c"
}


SerializableObjectModelTDocumentTest* serializable_object_model_tdocument_test_new (void) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	return serializable_object_model_tdocument_test_construct (TYPE_SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST);
#line 2718 "SerializableObjectModel-TDocument-Test.c"
}


static void serializable_object_model_tdocument_test_class_init (SerializableObjectModelTDocumentTestClass * klass) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializableObjectModel-TDocument-Test.vala"
	serializable_object_model_tdocument_test_parent_class = g_type_class_peek_parent (klass);
#line 2725 "SerializableObjectModel-TDocument-Test.c"
}


static void serializable_object_model_tdocument_test_instance_init (SerializableObjectModelTDocumentTest * self) {
}


/**
 *
 *  GXml.EnumerationTest.vala
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2014-2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType serializable_object_model_tdocument_test_get_type (void) {
	static volatile gsize serializable_object_model_tdocument_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_object_model_tdocument_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableObjectModelTDocumentTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_object_model_tdocument_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableObjectModelTDocumentTest), 0, (GInstanceInitFunc) serializable_object_model_tdocument_test_instance_init, NULL };
		GType serializable_object_model_tdocument_test_type_id;
		serializable_object_model_tdocument_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializableObjectModelTDocumentTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_object_model_tdocument_test_type_id__volatile, serializable_object_model_tdocument_test_type_id);
	}
	return serializable_object_model_tdocument_test_type_id__volatile;
}



